@@ -8,7 +8,7 @@ dof_ml1 <- function(model) {
 
   re_groups <- insight::get_random(model)
 
-  parameters <- insight::find_parameters(model)[["conditional"]]
+  parameters <- insight::find_parameters(model, effects = "fixed")[["conditional"]]
   predictors <- insight::find_predictors(model, effects = "fixed", component = "conditional", flatten = TRUE)
   predictors <- setdiff(predictors, names(re_groups))
 
@@ -31,7 +31,8 @@ dof_ml1 <- function(model) {
   ddf[] <- ltab$ddf[ii]
 
   out <- numeric(length = length(parameters))
-  out[which("(Intercept)" != parameters)] <- ddf[term_assignment]
+  ## TODO number of items to replace is not a multiple of replacement length
+  suppressWarnings(out[which("(Intercept)" != parameters)] <- ddf[term_assignment])
   if (has_intcp) out[which("(Intercept)" == parameters)] <- min(ddf)
 
   stats::setNames(out, parameters)
@@ -42,9 +43,16 @@ dof_ml1 <- function(model) {
 
 #' @importFrom stats ave var
 .get_df_ml1_approx <- function(x, g) {
+  if (!is.factor(g)) {
+    g <- as.factor(g)
+  }
   m <- nlevels(g)
   n <- length(x)
-  x <- as.numeric(x)
+  if (is.character(x)) {
+    x <- as.numeric(as.factor(x))
+  } else {
+    x <- as.numeric(x)
+  }
   x.bar <- stats::ave(x, g)
   var.within <- stats::var(x - x.bar)
   var.between <- stats::var(x.bar)
