@@ -1,3 +1,4 @@
+#' @importFrom insight clean_names
 #' @keywords internal
 .clean_parameter_names <- function(x, full = FALSE) {
   # return if x is empty
@@ -33,6 +34,9 @@
       } else {
         x <- trimws(sub("I\\((.*)\\)(.*)", "\\1", x))
       }
+      # some exceptions here...
+    } else if (full && pattern[j] == "scale" && any(grepl("scale\\(", x))) {
+      x[grepl("scale\\(", x)] <- insight::clean_names(x[grepl("scale\\(", x)])
     } else {
       p <- paste0(pattern[j], "\\(((\\w|\\.)*)\\)(.*)")
       x <- trimws(sub(p, "\\1\\3", x))
